@@ -9,6 +9,11 @@ DATABASES = {
     }
 }
 
+try:
+    from local import *
+except ImportError:
+    pass
+
 AUTH_USER_MODEL = 'tests.CustomUser'
 
 NOPASSWORD_LOGIN_CODE_TIMEOUT = 900
@@ -50,4 +55,4 @@ MIDDLEWARE_CLASSES = (
 
 ROOT_URLCONF = 'tests.urls'
 
-EMAIL_BACKEND = 'django.core.mail.backends.dummy.EmailBackend'
\ No newline at end of file
+EMAIL_BACKEND = 'django.core.mail.backends.dummy.EmailBackend'
